/**
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *  http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.strategicbase.webexporter.phantom;

import java.util.Map;

/**
 * <p>
 * {@link PDFExporter} exports a HTML to a PDF.
 * </p>
 * 
 * @author sboyina
 * 
 */
public class PDFExporter extends BaseExporter {

	/**
	 * Enumeration of available paper sizes.
	 * 
	 */
	public static enum PaperSize {
		A3("A3"), A4("A4"), A5("A5"), LEGAL("Legal"), LETTER("Letter"), TABLOID(
				"Tabloid");

		String size = "";

		PaperSize(String size) {
			this.size = size;
		}

		public String toString() {
			return size;
		}
	}

	/**
	 * Enumeration of available orientations.
	 */
	public static enum Orientaion {
		LANDSCAPE("landscape"), PORTRAIT("portrait");

		String orientaion = "";

		Orientaion(String orientaion) {
			this.orientaion = orientaion;
		}

		public String toString() {
			return orientaion;
		}
	}

	private PaperSize paperSize = PaperSize.A4;
	private Orientaion orientaion = Orientaion.PORTRAIT;
	private int border = 1;

	public PDFExporter() {
		super("pdf");
	}

	public PaperSize getPaperSize() {
		return paperSize;
	}

	public void setPaperSize(PaperSize paperSize) {
		this.paperSize = paperSize;
	}

	public void setPaperSizeByName(String paperSizeName) {
		this.paperSize = PaperSize.valueOf(paperSizeName);
	}

	public Orientaion getOrientaion() {
		return orientaion;
	}

	public void setOrientaion(Orientaion orientaion) {
		this.orientaion = orientaion;
	}

	public void setOrientaionByName(String orientationName) {
		this.orientaion = Orientaion.valueOf(orientationName);
	}

	public int getBorder() {
		return border;
	}

	/**
	 * @param border
	 *            border to set in the PDF to be generated.
	 */
	public void setBorder(int border) {
		this.border = border;
	}

	protected Map<String, String> getOptionsMap() {
		Map<String, String> optionMap = super.getOptionsMap();
		optionMap.put("format", paperSize.toString());
		optionMap.put("orientation", orientaion.toString());
		optionMap.put("border", border + "cm");
		return optionMap;
	}
}
