/**
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *  http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.strategicbase.webexporter.phantom;

import java.io.File;

import org.junit.Before;
import org.junit.Test;

import com.strategicbase.webexporter.ExportException;
import com.strategicbase.webexporter.phantom.PDFExporter;

/**
 * Unit test for simple App.
 */
public class PDFExporterTest extends ExporterTestBase {

	private PDFExporter pdfExporter;

	@Before
	public void initialize() throws Exception {
		pdfExporter = new PDFExporter();
	}

	@Test
	public void testURLExportAsPDF() throws Exception {
		pdfExporter.setRenderTime(5000);
		pdfExporter.setMaxExportTimeAlowed(30000);
		File outputFile = pdfExporter
				.export(getTestURL());
		assertExistence(outputFile);
	}

	@Test
	public void testFileExportAsPDF() throws ExportException {
		File outputFile = pdfExporter.export(getTestFile());
		assertExistence(outputFile);
	}

	/*
	 * Set render timeout more than max export time. Then, check whether the
	 * process is failing with an exception.
	 */
	@Test(expected = ExportException.class)
	public void testExportTimeout() throws ExportException {
		pdfExporter.setRenderTime(200);
		pdfExporter.setMaxExportTimeAlowed(100);
		pdfExporter.export(new File(
				getResourcePath("classpath:html/webshot.html")));
	}

	@Test
	public void testSVGStringExportAsPDF() throws Exception {
		File outputFile = pdfExporter.export(new File(
				getResourcePath("classpath:svg/testFile.svg")));
		assertExistence(outputFile);
	}
}
